"use client"
import { CheckItemIconState, CheckItemType } from "@/types/CheckItem"
import { Icon } from "@iconify/react/dist/iconify.js"
import useSWRImmutable from "swr/immutable"

type CheckItemProps = CheckItemType

const fetcher = (url: string | URL | Request) =>
  fetch(url).then((r) => r.json())

const icon = {
  ok: (
    <Icon
      icon='material-symbols:check-circle-outline-rounded'
      className='stroke-1 text-success h-6 w-6 shrink-0'
    />
  ),
  loading: <span className='loading loading-spinner loading-xs'></span>,
  info: (
    <Icon
      icon='material-symbols:info-outline'
      className='stroke-1 text-info h-6 w-6 shrink-0'
    />
  ),
  error: (
    <Icon
      icon='material-symbols:error-outline'
      className='stroke-1 text-error h-6 w-6 shrink-0'
    />
  ),
}

export default function CheckItem({ name, url, content }: CheckItemProps) {
  const { data, error, isLoading } = useSWRImmutable<any, Error>(url, fetcher)

  return (
    <>
      <div role='alert' className='alert'>
        {error
          ? icon["error"]
          : isLoading
          ? icon["loading"]
          : data != undefined
          ? icon[content(data).state]
          : null}

        <div>
          <span className="mr-4"><b>{name}</b></span>

          <span>
            {data != undefined
              ? content(data).text
              : error != null
              ? `无法获取: ${error.name}`
              : null}
          </span>
        </div>
      </div>
    </>
  )
}
